pub struct LiteralRule {
pub host_match: String,
pub host_replacement: String,
pub path_prefix_match: String,
pub path_prefix_replacement: String,
}Expand description
A literal match and replacement rule.
Examples
Replaces example.com with test.example.com for all packages
{
host_match: "example.com"
host_replacement: "test.example.com"
path_prefix_match: "/"
path_prefix_replacement: "/"
}Replaces example.com with test.example.com for fuchsia-pkg://example.com/rolldice. A package called “rolldice” in another repo would not be rewritten.
{
host_match: "example.com"
host_replacement: "test.example.com"
path_prefix_match: "/rolldice"
path_prefix_replacement: "/rolldice"
}Fields
host_match: StringThe exact hostname to match.
host_replacement: StringThe new hostname to replace the matched host_match with.
path_prefix_match: StringThe absolute path to a package or directory to match against.
If path_prefix_match ends with ‘/’, it will match any packages or
subdirectories below the matched path.
If path_prefix_match does not end with ‘/’, it will be interpreted as
as an exact match.
Examples
“/example” only matches a package called “example” at the root of the repo. “/parent/examples” and “/examples” would not match.
“/example/” would match any package under the “example” path at the root of the repo. For example, “/example/”, “/example/package” would both match.
path_prefix_replacement: StringThe absolute path to a single package or a directory to replace the
matched path_prefix_match with.
path_prefix_match and path_prefix_replacement must both match
directories or both match exact packages. Mixing the two forms is not
allowed.